@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.103 2006/10/02 14:08:55 davyd Exp $ */
+/* $Id: gweather-pref.c 10529 2007-11-22 07:59:29Z callum $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -22,7 +22,6 @@
 #include <string.h>
 #include <assert.h>
 #include <ctype.h>
-#include <langinfo.h>
 #include <locale.h>
 
 #include <gnome.h>
@@ -785,7 +784,7 @@ gweather_pref_create (GWeatherPref *pref)
     gtk_dialog_set_default_response (GTK_DIALOG (pref), GTK_RESPONSE_CLOSE);
     gtk_dialog_set_has_separator (GTK_DIALOG (pref), FALSE);
     gtk_container_set_border_width (GTK_CONTAINER (pref), 5);
-    gtk_window_set_resizable (GTK_WINDOW (pref), FALSE);
+    gtk_window_set_resizable (GTK_WINDOW (pref), TRUE);
     gtk_window_set_screen (GTK_WINDOW (pref),
 			   gtk_widget_get_screen (GTK_WIDGET (pref->priv->applet->applet)));
 
